@@ -1,5 +1,6 @@
 use swc_common::plugin::Serialized;
 
+#[cfg(target_arch = "wasm32")] // Allow testing
 extern "C" {
     fn __emit_diagnostics(bytes_ptr: i32, bytes_ptr_len: i32);
     fn __free(bytes_ptr: i32, size: i32) -> i32;
@@ -13,14 +14,16 @@ extern "C" {
 pub struct PluginDiagnosticsEmitter {}
 
 impl swc_common::errors::Emitter for PluginDiagnosticsEmitter {
+    #[cfg_attr(not(target_arch = "wasm32"), allow(unused))]
     fn emit(&mut self, db: &swc_common::errors::DiagnosticBuilder<'_>) {
         let diag =
             Serialized::serialize(&*db.diagnostic).expect("Should able to serialize Diagnostic");
         let diag_ref = diag.as_ref();
 
-        let ptr = diag_ref.as_ptr() as _;
+        let ptr = diag_ref.as_ptr() as i32;
         let len = diag_ref.len() as i32;
 
+        #[cfg(target_arch = "wasm32")] // Allow testing
         unsafe {
             __emit_diagnostics(ptr, len);
         }
